package main

import (
	"fmt"
	"github.com/Tinkerforge/go-api-bindings/ambient_light_v2_bricklet"
	"github.com/Tinkerforge/go-api-bindings/ipconnection"
)

const ADDR string = "localhost:4223"
const UID string = "XYZ" // Change XYZ to the UID of your Ambient Light Bricklet 2.0.

func main() {
	ipcon := ipconnection.New()
	defer ipcon.Close()
	al, _ := ambient_light_v2_bricklet.New(UID, &ipcon) // Create device object.

	ipcon.Connect(ADDR) // Connect to brickd.
	defer ipcon.Disconnect()
	// Don't use device before ipcon is connected.

	al.RegisterIlluminanceCallback(func(illuminance uint32) {
		fmt.Printf("Illuminance: %f lx\n", float64(illuminance)/100.0)
	})

	// Set period for illuminance receiver to 1s (1000ms).
	// Note: The illuminance callback is only called every second
	//       if the illuminance has changed since the last call!
	al.SetIlluminanceCallbackPeriod(1000)

	fmt.Print("Press enter to exit.")
	fmt.Scanln()

}
